@@ -16,10 +16,10 @@ from itemloaders.processors import TakeFirst
 def parse_time(values):
     for value in values:
         # Expecting a single hour like this: "4" or "15"
-        match_time = re.match(r'(\d+)', value)
+        match_time = re.match(r'^(\d+)$', value)
 
         # Expecting a time interval string like this: "04:15-04:30"
-        match_time_interval = re.match(r'(\d\d):(\d\d)-(\d\d):(\d\d)', value)
+        match_time_interval = re.match(r'^(\d\d):(\d\d)-(\d\d):(\d\d)$', value)
         if match_time is not None:
             # The "- 1" is because the time given is the ending time; values
             # start with 1 (representing interval 00:00 - 01:00) and end with 24
